Boost logo

Boost-Commit :

Subject: [Boost-commit] svn:boost r66380 - sandbox/icl
From: afojgo_at_[hidden]
Date: 2010-11-03 11:50:41


Author: jofaber
Date: 2010-11-03 11:50:34 EDT (Wed, 03 Nov 2010)
New Revision: 66380
URL: http://svn.boost.org/trac/boost/changeset/66380

Log:
Updated readme and release note files.
Text files modified:
   sandbox/icl/README_ICL.TXT | 89 ++++++++++++++++++----
   sandbox/icl/README_ICL_PLUS.TXT | 154 +++++++++++++++++++++++++--------------
   sandbox/icl/icl_4_0_0_plus.txt | 33 +++-----
   sandbox/icl/icl_4_0_0_plus_standalone.txt | 35 +++-----
   sandbox/icl/install_libs.bat | 4
   sandbox/icl/install_libs.sh | 4
   6 files changed, 200 insertions(+), 119 deletions(-)

Modified: sandbox/icl/README_ICL.TXT
==============================================================================
--- sandbox/icl/README_ICL.TXT (original)
+++ sandbox/icl/README_ICL.TXT 2010-11-03 11:50:34 EDT (Wed, 03 Nov 2010)
@@ -1,5 +1,5 @@
 /*-----------------------------------------------------------------------------+
-Interval Template Library
+Interval Container Library (Boost.Icl)
 Author: Joachim Faulhaber
 Copyright (c) 2007-2010: Joachim Faulhaber
 Copyright (c) 1999-2006: Cortex Software GmbH, Kantstrasse 57, Berlin
@@ -9,12 +9,13 @@
            http://www.boost.org/LICENSE_1_0.txt)
 +-----------------------------------------------------------------------------*/
 
-Interval Template Library (Boost.Itl) 3.2.1 Review Version Update 2
-===================================================================
+Interval Container Library (Boost.Icl) 4.0.0 Inclusion Version for boost 1.46
+=============================================================================
 Abstract:
 =========
 
-The Interval Template Library (Itl) provides intervals
+The Boost Interval Container Library (Icl) formerly known
+as Interval Template Library (Itl) provides intervals
 and two kinds of interval containers: Interval_sets and
 interval_maps. Interval_sets and maps can be used just
 as the sets or maps of elements. Yet they are much more
@@ -34,14 +35,59 @@
 feature is called aggregate on overlap.
 
 
-NOTE: Boost.Itl is not an official boost library.
-Boost.Itl is submitted for review which will probably take
-place end of February 2010.
+NOTE: Boost.Icl has been accepted into the Boost Library
+Collection on April 18, 2010. This is the library version
+prepared for inclusion into Boost 1.46.0.
+
 
 
 Release Notes:
 ==============
 
+* Boost.Icl 4.0.0 (Inclusion Version for Boost 1.46.0)
+------------------------------------------------------------------------
++ Tested Compilers: gcc-3.4.4, gcc-4.4.1,
+ msvc-8.0, msvc-9.0, msvc-10.0.
+
++ The library has been renamed from
+ Interval Template Library (ITL) to
+ Interval Container Library (ICL)
+ Its namespace is now icl instead of itl.
+
++ Introduction of dynamically bounded and statically bounded intervals
+ - The 'universal' interval class itl::interval has been replaced by
+ - dynamically bounded discrete_interval and continuous_interval
+ - statically bounded right_open_interval, left_open_interval
+ icl::closed_interval and icl::open_interval and a uniform set of
+ namespace global functions or interval_concept for them.
+ - Added functions 'distance' and 'inner_complement' for intervals.
+
++ User defined interval types are now customizable
+ - A interval_trait and dynamic_interval_trait template describes
+ the generic properties of the interval concept ...
+ - and allows to customize the icl library for user defined interval
+ types.
+
++ Extraction of namespace global functions.
+ - Member functions have been extracted form class templates as long
+ as they are not needed to maintain type invariants.
+ - The sets of namespace global functions build concepts
+ icl::element_set, icl::element_map,
+ icl::interval_set, icl::interval_map
+ - Functions have been renamed to conform existing standards
+ (ISO/OGC).
+ - std::set and other stl conformant set types are models of the
+ icl's element_set concept. Class template icl::set has been
+ removed.
+ - Member functions for element iterations are extracted from
+ the class templates.
+
++ Names, referred to as 'colorful terminology' have been renamed
+ - neutron -> identity_element
+ - unon -> unit_element
+ - ... and also their occurrence in composite identifiers
+
+
 * Boost.Itl 3.2.1 (Review Version, update 2)
 ------------------------------------------------------------------------
 + Tested Compilers: gcc-3.4.4, gcc-4.3.2, gcc-4.4.1,
@@ -85,16 +131,23 @@
 Content:
 ========
 
-itl.html html-documentation referring to
- libs/itl/doc/html/index.html
+icl.html html-documentation referring to
+ libs/icl/doc/html/index.html
 doc/html/images Images for the html docs. You may delete this, if you
- integrate itl_plus into an existing boost installation.
+ integrate icl_plus into an existing boost installation.
+
+boost/icl Interval containers, operators, algorithms
+boost/icl/type_traits Metafunctions for types
+boost/icl/concept Sets of namespace global functions that make up icl
+ concepts.
+boost/icl/predicates Some boolean function objects
+boost/icl/detail Implementation details
+
+libs/icl/example Example programs
+libs/icl/test Test suite
+libs/icl/doc Quickbook documentation
+libs/icl/doc/html html documentation (Generated by Quickbook)
+
 
-boost/itl Interval containers, operators, algorithms
-boost/itl/type_traits Metafunctions for types
-boost/itl/detail Implementation details
-
-libs/itl/example Example programs
-libs/itl/test Test suite
-libs/itl/doc Quickbook documentation
-libs/itl/doc/html html documentation (Generated by Quickbook)
+Enjoy
+Joachim Faulhaber

Modified: sandbox/icl/README_ICL_PLUS.TXT
==============================================================================
--- sandbox/icl/README_ICL_PLUS.TXT (original)
+++ sandbox/icl/README_ICL_PLUS.TXT 2010-11-03 11:50:34 EDT (Wed, 03 Nov 2010)
@@ -1,5 +1,5 @@
 /*-----------------------------------------------------------------------------+
-Interval Template Library
+Interval Container Library (Boost.Icl)
 Author: Joachim Faulhaber
 Copyright (c) 2007-2010: Joachim Faulhaber
 Copyright (c) 1999-2006: Cortex Software GmbH, Kantstrasse 57, Berlin
@@ -9,16 +9,17 @@
            http://www.boost.org/LICENSE_1_0.txt)
 +-----------------------------------------------------------------------------*/
 
-Interval Template Library (Boost.Itl) 3.2.1 Review Version Update 2
-===================================================================
+Interval Container Library (Boost.Icl) 4.0.0 Inclusion Version for boost 1.46
+=============================================================================
 PLUS
-Itl_xt Extended by generalized cross tables (cubes) AND
+Icl_xt Extended by generalized cross tables (cubes) AND
 validate A law based test automaton (LaBatea).
 
 Abstract:
 =========
 
-The Interval Template Library (Itl) provides intervals
+The Boost Interval Container Library (Icl) formerly known
+as Interval Template Library (Itl) provides intervals
 and two kinds of interval containers: Interval_sets and
 interval_maps. Interval_sets and maps can be used just
 as the sets or maps of elements. Yet they are much more
@@ -37,23 +38,67 @@
 intervals, that are stored in the interval_map. This
 feature is called aggregate on overlap.
 
-Itl_xt's cubes and the law based test automaton (LaBatea)
+Icl_xt's cubes and the law based test automaton (LaBatea)
 are not yet proposed and prepared as Boost libraries.
 But LaBatea has been used in the development of the
-itl as test automaton and for checking sematical
+icl as test automaton and for checking sematical
 concepts.
 
-NOTE: Neither of the tree libraries itl, itl_xt and validate
-is an official boost library yet. They are named Boost.Itl,
-Boost.Itl_xt and Boost.Validate here, because they are already
-organized in the boost centric directory structure.
 
-The core library Boost.Itl is submitted for review which
-will probably take place end of February 2010.
+NOTE: The core library, Boost.Icl, has been accepted into
+the Boost Library Collection on April 18, 2010. This is
+the library version prepared for inclusion into Boost 1.46.0.
+
+The extended parts icl_xt and validate are not Boost libraries.
+
 
 Release Notes:
 ==============
 
+* Boost.Icl 4.0.0 (Inclusion Version for Boost 1.46.0)
+------------------------------------------------------------------------
++ Tested Compilers: gcc-3.4.4, gcc-4.4.1,
+ msvc-8.0, msvc-9.0, msvc-10.0.
+
++ The library has been renamed from
+ Interval Template Library (ITL) to
+ Interval Container Library (ICL)
+ Its namespace is now icl instead of itl.
+
++ Introduction of dynamically bounded and statically bounded intervals
+ - The 'universal' interval class itl::interval has been replaced by
+ - dynamically bounded discrete_interval and continuous_interval
+ - statically bounded right_open_interval, left_open_interval
+ icl::closed_interval and icl::open_interval and a uniform set of
+ namespace global functions or interval_concept for them.
+ - Added functions 'distance' and 'inner_complement' for intervals.
+
++ User defined interval types are now customizable
+ - A interval_trait and dynamic_interval_trait template describes
+ the generic properties of the interval concept ...
+ - and allows to customize the icl library for user defined interval
+ types.
+
++ Extraction of namespace global functions.
+ - Member functions have been extracted form class templates as long
+ as they are not needed to maintain type invariants.
+ - The sets of namespace global functions build concepts
+ icl::element_set, icl::element_map,
+ icl::interval_set, icl::interval_map
+ - Functions have been renamed to conform existing standards
+ (ISO/OGC).
+ - std::set and other stl conformant set types are models of the
+ icl's element_set concept. Class template icl::set has been
+ removed.
+ - Member functions for element iterations are extracted from
+ the class templates.
+
++ Names, refered to as 'colorful terminology' have been renamed
+ - neutron -> identity_element
+ - unon -> unit_element
+ - ... and also their occurrence in composite identifiers
+
+
 * Boost.Itl 3.2.1 (Review Version, update 2)
 ------------------------------------------------------------------------
 + Tested Compilers: gcc-3.4.4, gcc-4.3.2, gcc-4.4.1,
@@ -121,82 +166,83 @@
 Content:
 ========
 
-=== Itl =======================================================================
-itl.html html-documentation referring to
- libs/itl/doc/html/index.html
+=== Icl =======================================================================
+icl.html html-documentation referring to
+ libs/icl/doc/html/index.html
 doc/html/images Images for the html docs. You may delete this, if you
- integrate itl_plus into an existing boost installation.
+ integrate icl_plus into an existing boost installation.
 
-boost/itl Interval containers, operators, algorithms
-boost/itl/type_traits Metafunctions for types
-boost/itl/detail Implementation details
-
-libs/itl/example Example programs
-libs/itl/test Test suite
-libs/itl/doc Quickbook documentatons
-libs/itl/doc/html html documentation from Quickbook sources for Boost.Itl
-libs/itl/build/win32 vc9_all.sln. solution file for msvc-9 including LaBatea
- programs.
+boost/icl Interval containers, operators, algorithms
+boost/icl/type_traits Metafunctions for types
+boost/icl/concept Sets of namespace global functions that make up icl
+ concepts.
+boost/icl/predicates Some boolean function objects
+boost/icl/detail Implementation details
+
+libs/icl/example Example programs
+libs/icl/test Test suite
+libs/icl/doc Quickbook documentatons
+libs/icl/doc/html html documentation from Quickbook sources for Boost.Icl
                                                 
-=== Itl extended ==============================================================
-boost/itl_xt Headers of extended itl classes like cubes.
-libs/itl_xt/example Example programs
-libs/itl_xt/test Test programs
+=== Icl extended ==============================================================
+boost/icl_xt Headers of extended icl classes like cubes.
+libs/icl_xt/example Example programs
+libs/icl_xt/test Test programs
 
 === LaBatea ===================================================================
 boost/validate Headers of the law based test automaton (LaBatea).
-libs/validate/example Projects for validating Boost.Itl with LaBatea.
+libs/validate/example Projects for validating Boost.Icl with LaBatea.
 libs/validate/src Sourcefiles.
 
-=== Itl, Itl_xt and Validate =================================================
-itl_plus_doxy.html Html file that contains a link to the doygen docs:
-libs/itl/doxy_doc/doxygen_output/html/index.html: html documentation generated
+=== Icl, Icl_xt and Validate =================================================
+icl_plus_doxy.html Html file that contains a link to the doygen docs:
+libs/icl/doxy_doc/doxygen_output/html/index.html: html documentation generated
                         by doxygen that covers a minimal documentation for
- itl_xt and validate (LaBatea).
-itl.html Html file that contains a link to the quickbook docs:
-libs/itl/doc/html/index.html: html documentation generated by doxygen
- that covers a minimal documentation for itl_xt and
+ icl_xt and validate (LaBatea).
+icl.html Html file that contains a link to the quickbook docs:
+libs/icl/doc/html/index.html: html documentation generated by doxygen
+ that covers a minimal documentation for icl_xt and
                         validate (LaBatea).
 
-itl_plus and boost
+icl_plus and boost
 ==================
                                                 
 The interval template library comes in the boost centric project structure
-<boost-root>/boost/itl/ contains all include files
-<boost-root>/boost/itl/ examples, tests and documentation.
-So you can integrate itl, itl_xt and validate into an existing boost
+<boost-root>/boost/icl/ contains all include files
+<boost-root>/boost/icl/ examples, tests and documentation.
+So you can integrate icl, icl_xt and validate into an existing boost
 installation by copying
-boost/{itl,itl_xt,validate} to the <boost-root>/boost directory and
-libs/{itl,itl_xt,validate} to the <boost-root>/libs directory.
+boost/{icl,icl_xt,validate} to the <boost-root>/boost directory and
+libs/{icl,icl_xt,validate} to the <boost-root>/libs directory.
 
-In subdirectories like libs/itl/example, libs/itl/test you will find a
+In subdirectories like libs/icl/example, libs/icl/test you will find a
 Jamfile.v2 that allows you to compile the related code with bjam.
 
 To learn more about boost libraries and bjam refer to the boost web site.
 http://www.boost.org/
 
 
-itl_plus_standalone
+icl_plus_standalone
 ===================
 
-You can also download itl_plus_standalone. Included in itl_plus_standalone are
-all sources from the boost libraries that are needed to compile itl code,
+You can also download icl_plus_standalone. Included in icl_plus_standalone are
+all sources from the boost libraries that are needed to compile icl code,
 examples and tests. For msvc-9 users it contains sln and vcproj files and a few
 precompiled libraries needed by examples and test projects. If you are lucky
 you can compile and run using
 
-libs/itl/example/vc9_itl_examples.sln Examples for the itl
-libs/itl/test/vc9_itl_tests.sln Boost unit tests for the itl
-libs/validate/examples/vc9_validate_examples.sln Law based tests for itl
+libs/icl/example/vc9_icl_examples.sln Examples for the icl
+libs/icl/test/vc9_icl_tests.sln Boost unit tests for the icl
+libs/validate/examples/vc9_validate_examples.sln Law based tests for icl
 libs/validate/test/vc9_validate_test.sln Law based tests as unit tests
-libs/itl/build/win32/vc9_all.sln Almost everything in one project
+libs/icl/build/win32/vc9_all.sln Almost everything in one project
 
 If this does not work out of the box, you can reinstall the boost date_time and
 test binaries using
 
 install_libs.bat
 
-from the command line at the root directory of itl_plus_standalone.
+from the command line at the root directory of icl_plus_standalone.
 If this still does not work, get a new version of bjam (boost-jam) at
 http://sourceforge.net/projects/boost/files/boost-jam/
 

Modified: sandbox/icl/icl_4_0_0_plus.txt
==============================================================================
--- sandbox/icl/icl_4_0_0_plus.txt (original)
+++ sandbox/icl/icl_4_0_0_plus.txt 2010-11-03 11:50:34 EDT (Wed, 03 Nov 2010)
@@ -1,26 +1,17 @@
-File itl_plus_3_2_1.zip or
-File itl_plus_3_2_1.tar.gz
+File icl_plus_4_0_0.zip or
+File icl_plus_4_0_0.tar.gz
 
-+ itl_plus_3_2_1 is for users of different platforms that have a version of the
++ icl_plus_4_0_0 is for users of different platforms that have a version of the
   boost libraries and the build tool bjam installed.
-+ You can copy itl_plus/boost/{itl,itl_xt,validate} to the boost directory
- and itl_plus/libs/{itl,itl_xt,validate} to the libs directory of your boost
++ You can copy icl_plus/boost/{icl,icl_xt,validate} to the boost directory
+ and icl_plus/libs/{icl,icl_xt,validate} to the libs directory of your boost
   installation and then run all examples and tests using bjam.
 
 Changes
-Version 3.2.1. (Boost review version update 2)
-+ All source files are now following the boost project conventions
- <prj-root>/boost/itl/... Header files *.hpp of the library itl
- <prj-root>/libs/itl/... Examples, Tests, Documentation for itl
-+ Added class template interval_bitset for large compressed bitsets.
-+ Added itl::insert_iterator itl::add_iterator to fill interval containers from
- stl containers of intervals.
-+ Added element iteration for all interval containers.
-+ Set theoretic operations union (+ += | |=), difference (- -=), intersection
- (& &=) and symmetric difference (^ ^=) are now available as namespace global
- operators in an infix and an assigning variant for all interval containers and
- many overloads combining elements, segments and useful combinations of
- different interval containers.
-+ Operators for intersection changed from (* *=) to (& &=).
-+ Interval constructing functions changed from global function templates to
- static functions.
\ No newline at end of file
+Version 4.0.0. (Inclusion version for Boost 1.46.0)
++ Renaming of the library to Interval Container Library (ICL)
++ Added intervals with static bound types, which are smaller and faster.
++ Added an interval concept that is customizable.
++ User defined interval class types can be used with the library easily.
++ Renamed functions according to existing standards (ISO/OCG).
+

Modified: sandbox/icl/icl_4_0_0_plus_standalone.txt
==============================================================================
--- sandbox/icl/icl_4_0_0_plus_standalone.txt (original)
+++ sandbox/icl/icl_4_0_0_plus_standalone.txt 2010-11-03 11:50:34 EDT (Wed, 03 Nov 2010)
@@ -1,27 +1,18 @@
-File itl_plus_3_2_1_standalone.7z or
-File itl_plus_3_2_1_standalone.zip
+File icl_plus_4_0_0_standalone.7z or
+File icl_plus_4_0_0_standalone.zip
 
-+ itl_plus_3_2_1_standalone is for users of msvc (visual studio) who do not have
++ icl_plus_4_0_0_standalone is for users of msvc (visual studio) who do not have
   a version of the boost libraries installed and do not want to get one or are
   so busy that they think they do not have time to do so ;)
-+ itl_plus_3_2_1_standalone contains all parts of boost that are needed to run
- itl code, examples and tests under a ms windows os (vista, windows7) using
- msvc-9 (visual studio 2008).
++ icl_plus_4_0_0_standalone contains all parts of boost that are needed to run
+ icl code, examples and tests under a ms windows os (vista, windows7) using
+ msvc-9/10.
 
 Changes
-Version 3.2.1. (Boost review version update 2)
-+ All source files are now following the boost project conventions
- <prj-root>/boost/itl/... Header files *.hpp of the library itl
- <prj-root>/libs/itl/... Examples, Tests, Documentation for itl
-+ Added class template interval_bitset for large compressed bitsets.
-+ Added itl::insert_iterator itl::add_iterator to fill interval containers from
- stl containers of intervals.
-+ Added element iteration for all interval containers.
-+ Set theoretic operations union (+ += | |=), difference (- -=), intersection
- (& &=) and symmetric difference (^ ^=) are now available as namespace global
- operators in an infix and an assigning variant for all interval containers and
- many overloads combining elements, segments and useful combinations of
- different interval containers.
-+ Operators for intersection changed from (* *=) to (& &=).
-+ Interval constructing functions changed from global function templates to
- static functions.
\ No newline at end of file
+Version 4.0.0. (Inclusion version for Boost 1.46.0)
++ Renaming of the library to Interval Container Library (ICL)
++ Added intervals with static bound types, which are smaller and faster.
++ Added an interval concept that is customizable.
++ User defined interval class types can be used with the library easily.
++ Renamed functions according to existing standards (ISO/OCG).
+

Modified: sandbox/icl/install_libs.bat
==============================================================================
--- sandbox/icl/install_libs.bat (original)
+++ sandbox/icl/install_libs.bat 2010-11-03 11:50:34 EDT (Wed, 03 Nov 2010)
@@ -1,5 +1,5 @@
 rem Installs boost::date_time and boost::test so all examples and tests can be run
-rem for the Interval Template Library (ITL). You do not need to run this script,
+rem for the Interval Container Library (ICL). You do not need to run this script,
 rem if you have a working installation of the boost libraries.
 
 @echo off
@@ -22,7 +22,7 @@
 echo toolset : The compiler 'toolset' will be used with bjam.
 echo If the first argument is omitted 'msvc' is used as toolset.
 echo Installs boost::date_time and boost::test so all examples and tests can be run
-echo for the Interval Template Library (ITL). You do not need to run this script,
+echo for the Interval Container Library (ICL). You do not need to run this script,
 echo if you have a working installation of the boost libraries.
 
 :end

Modified: sandbox/icl/install_libs.sh
==============================================================================
--- sandbox/icl/install_libs.sh (original)
+++ sandbox/icl/install_libs.sh 2010-11-03 11:50:34 EDT (Wed, 03 Nov 2010)
@@ -1,7 +1,7 @@
 #!/bin/sh
 
 # Installs boost::date_time and boost::test so all examples and tests can be run
# for the Interval Template Library (ITL). You do not need to run this script,
 # if you have a working installation of the boost libraries.
 
 for option
@@ -18,7 +18,7 @@
   echo " toolset : The compiler 'toolset' will be used with bjam.";
   echo " If the first argument is omitted 'gcc' is used as toolset.";
   echo "Installs boost::date_time and boost::test so all examples and tests can be run";
- echo "for the Interval Template Library (ITL). You do not need to run this script, ";
+ echo "for the Interval Container Library (ICL). You do not need to run this script, ";
   echo "if you have a working installation of the boost libraries.";
 else
   TOOLSET=$1;
@@ -1,7 +1,7 @@
 
 # Installs boost::date_time and boost::test so all examples and tests can be run
-# for the Interval Template Library (ITL). You do not need to run this script,
+# for the Interval Container Library (ICL). You do not need to run this script,
 # if you have a working installation of the boost libraries.
 


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk